// fonts-dejavu.css

// DejaVu Sans
@font-face {
  font-family: 'DejaVuSans';
  src: url('woff2/DejaVuSans-BoldOblique.woff2') format('woff2'),
       url('woff/DejaVuSans-BoldOblique.woff') format('woff'),
       url('ttf/DejaVuSans-BoldOblique.ttf') format('truetype');
  font-weight: bold;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSans';
  src: url('woff2/DejaVuSans-Oblique.woff2') format('woff2'),
       url('woff/DejaVuSans-Oblique.woff') format('woff'),
       url('ttf/DejaVuSans-Oblique.ttf') format('truetype');
  font-weight: normal;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSans';
  src: url('woff2/DejaVuSans-Bold.woff2') format('woff2'),
       url('woff/DejaVuSans-Bold.woff') format('woff'),
       url('ttf/DejaVuSans-Bold.ttf') format('truetype');
  font-weight: bold;
  font-style: normal;
}
@font-face {
  font-family: 'DejaVuSans';
  src: url('woff2/DejaVuSans-ExtraLight.woff2') format('woff2'),
       url('woff/DejaVuSans-ExtraLight.woff') format('woff'),
       url('ttf/DejaVuSans-ExtraLight.ttf') format('truetype');
  font-weight: lighter;
  font-style: normal;
}
@font-face {
  font-family: 'DejaVuSans';
  src: url('woff2/DejaVuSans.woff2') format('woff2'),
       url('woff/DejaVuSans.woff') format('woff'),
       url('ttf/DejaVuSans.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}

// DejaVu Sans Condensed
@font-face {
  font-family: 'DejaVuSansCondensed';
  src: url('woff2/DejaVuSansCondensed-BoldOblique.woff2') format('woff2'),
       url('woff/DejaVuSansCondensed-BoldOblique.woff') format('woff'),
       url('ttf/DejaVuSansCondensed-BoldOblique.ttf') format('truetype');
  font-weight: bold;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSansCondensed';
  src: url('woff2/DejaVuSansCondensed-Oblique.woff2') format('woff2'),
       url('woff/DejaVuSansCondensed-Oblique.woff') format('woff'),
       url('ttf/DejaVuSansCondensed-Oblique.ttf') format('truetype');
  font-weight: normal;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSansCondensed';
  src: url('woff2/DejaVuSansCondensed-Bold.woff2') format('woff2'),
       url('woff/DejaVuSansCondensed-Bold.woff') format('woff'),
       url('ttf/DejaVuSansCondensed-Bold.ttf') format('truetype');
  font-weight: bold;
  font-style: normal;
}
@font-face {
  font-family: 'DejaVuSansCondensed';
  src: url('woff2/DejaVuSansCondensed.woff2') format('woff2'),
       url('woff/DejaVuSansCondensed.woff') format('woff'),
       url('ttf/DejaVuSansCondensed.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}

// DejaVu Sans Mono
@font-face {
  font-family: 'DejaVuSansMono';
  src: url('woff2/DejaVuSansMono-BoldOblique.woff2') format('woff2'),
       url('woff/DejaVuSansMono-BoldOblique.woff') format('woff'),
       url('ttf/DejaVuSansMono-BoldOblique.ttf') format('truetype');
  font-weight: bold;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSansMono';
  src: url('woff2/DejaVuSansMono-Oblique.woff2') format('woff2'),
       url('woff/DejaVuSansMono-Oblique.woff') format('woff'),
       url('ttf/DejaVuSansMono-Oblique.ttf') format('truetype');
  font-weight: normal;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSansMono';
  src: url('woff2/DejaVuSansMono-Bold.woff2') format('woff2'),
       url('woff/DejaVuSansMono-Bold.woff') format('woff'),
       url('ttf/DejaVuSansMono-Bold.ttf') format('truetype');
  font-weight: bold;
  font-style: normal;
}
@font-face {
  font-family: 'DejaVuSansMono';
  src: url('woff2/DejaVuSansMono.woff2') format('woff2'),
       url('woff/DejaVuSansMono.woff') format('woff'),
       url('ttf/DejaVuSansMono.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}

// DejaVu Serif
@font-face {
  font-family: 'DejaVuSerif';
  src: url('woff2/DejaVuSerif-BoldItalic.woff2') format('woff2'),
       url('woff/DejaVuSerif-BoldItalic.woff') format('woff'),
       url('ttf/DejaVuSerif-BoldItalic.ttf') format('truetype');
  font-weight: bold;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSerif';
  src: url('woff2/DejaVuSerif-Italic.woff2') format('woff2'),
       url('woff/DejaVuSerif-Italic.woff') format('woff'),
       url('ttf/DejaVuSerif-Italic.ttf') format('truetype');
  font-weight: normal;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSerif';
  src: url('woff2/DejaVuSerif-Bold.woff2') format('woff2'),
       url('woff/DejaVuSerif-Bold.woff') format('woff'),
       url('ttf/DejaVuSerif-Bold.ttf') format('truetype');
  font-weight: bold;
  font-style: normal;
}
@font-face {
  font-family: 'DejaVuSerif';
  src: url('woff2/DejaVuSerif.woff2') format('woff2'),
       url('woff/DejaVuSerif.woff') format('woff'),
       url('ttf/DejaVuSerif.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}

// DejaVu Serif Condensed
@font-face {
  font-family: 'DejaVuSerifCondensed';
  src: url('woff2/DejaVuSerifCondensed-BoldItalic.woff2') format('woff2'),
       url('woff/DejaVuSerifCondensed-BoldItalic.woff') format('woff'),
       url('ttf/DejaVuSerifCondensed-BoldItalic.ttf') format('truetype');
  font-weight: bold;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSerifCondensed';
  src: url('woff2/DejaVuSerifCondensed-Italic.woff2') format('woff2'),
       url('woff/DejaVuSerifCondensed-Italic.woff') format('woff'),
       url('ttf/DejaVuSerifCondensed-Italic.ttf') format('truetype');
  font-weight: normal;
  font-style: italic, oblique;
}
@font-face {
  font-family: 'DejaVuSerifCondensed';
  src: url('woff2/DejaVuSerifCondensed-Bold.woff2') format('woff2'),
       url('woff/DejaVuSerifCondensed-Bold.woff') format('woff'),
       url('ttf/DejaVuSerifCondensed-Bold.ttf') format('truetype');
  font-weight: bold;
  font-style: normal;
}
@font-face {
  font-family: 'DejaVuSerifCondensed';
  src: url('woff2/DejaVuSerifCondensed.woff2') format('woff2'),
       url('woff/DejaVuSerifCondensed.woff') format('woff'),
       url('ttf/DejaVuSerifCondensed.ttf') format('truetype');
  font-weight: normal;
  font-style: normal;
}
